@@ -1,6 +1,8 @@
 # --
 # Kernel/Modules/AdminDynamicFieldMultiselect.pm - provides a dynamic fields text config view for admins
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# --
+# $Id: AdminDynamicFieldMultiselect.pm,v 1.7 2011/12/21 14:24:04 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,6 +19,9 @@ use Kernel::System::Valid;
 use Kernel::System::CheckItem;
 use Kernel::System::DynamicField;
 
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.7 $) [1];
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -135,14 +140,14 @@ sub _AddAction {
                 'The field does not contain only ASCII letters and numbers.';
         }
 
-        # get dynamic field list
-        my $DynamicFieldsList = $Self->{DynamicFieldObject}->DynamicFieldList(
-            Valid      => 0,
-            ResultType => 'HASH',
-        ) || {};
-
         # check if name is duplicated
-        my %DynamicFieldsList = %{$DynamicFieldsList};
+        my %DynamicFieldsList = %{
+            $Self->{DynamicFieldObject}->DynamicFieldList(
+                Valid      => 0,
+                ResultType => 'HASH',
+                )
+            };
+
         %DynamicFieldsList = reverse %DynamicFieldsList;
 
         if ( $DynamicFieldsList{ $GetParam{Name} } ) {
@@ -185,7 +190,7 @@ sub _AddAction {
 
     # set errors for possible values entries
     KEY:
-    for my $Key ( sort keys %{$PossibleValues} ) {
+    for my $Key ( keys %{$PossibleValues} ) {
 
         # check for empty original values
         if ( $Key =~ m{\A $Self->{EmptyString} (?: \d+)}smx ) {
@@ -276,7 +281,7 @@ sub _Change {
         );
     }
 
-    # get dynamic field data
+    # get dynamic filed data
     my $DynamicFieldData = $Self->{DynamicFieldObject}->DynamicFieldGet(
         ID => $FieldID,
     );
@@ -342,18 +347,6 @@ sub _ChangeAction {
         );
     }
 
-    # get dynamic field data
-    my $DynamicFieldData = $Self->{DynamicFieldObject}->DynamicFieldGet(
-        ID => $FieldID,
-    );
-
-    # check for valid dynamic field configuration
-    if ( !IsHashRefWithData($DynamicFieldData) ) {
-        return $Self->{LayoutObject}->ErrorScreen(
-            Message => "Could not get data for dynamic field $FieldID",
-        );
-    }
-
     if ( $GetParam{Name} ) {
 
         # check if name is lowercase
@@ -365,14 +358,14 @@ sub _ChangeAction {
                 'The field does not contain only ASCII letters and numbers.';
         }
 
-        # get dynamic field list
-        my $DynamicFieldsList = $Self->{DynamicFieldObject}->DynamicFieldList(
-            Valid      => 0,
-            ResultType => 'HASH',
-        ) || {};
-
         # check if name is duplicated
-        my %DynamicFieldsList = %{$DynamicFieldsList};
+        my %DynamicFieldsList = %{
+            $Self->{DynamicFieldObject}->DynamicFieldList(
+                Valid      => 0,
+                ResultType => 'HASH',
+                )
+            };
+
         %DynamicFieldsList = reverse %DynamicFieldsList;
 
         if (
@@ -385,19 +378,6 @@ sub _ChangeAction {
             $Errors{NameServerError}        = 'ServerError';
             $Errors{NameServerErrorMessage} = 'There is another field with the same name.';
         }
-
-        # if it's an internal field, it's name should not change
-        if (
-            $DynamicFieldData->{InternalField} &&
-            $DynamicFieldsList{ $GetParam{Name} } ne $FieldID
-            )
-        {
-
-            # add server error class
-            $Errors{NameServerError}        = 'ServerError';
-            $Errors{NameServerErrorMessage} = 'The name for this field should not change.';
-            $Param{InternalField}           = $DynamicFieldData->{InternalField};
-        }
     }
 
     if ( $GetParam{FieldOrder} ) {
@@ -432,11 +412,23 @@ sub _ChangeAction {
         );
     }
 
+    # get dynamic filed data
+    my $DynamicFieldData = $Self->{DynamicFieldObject}->DynamicFieldGet(
+        ID => $FieldID,
+    );
+
+    # check for valid dynamic field configuration
+    if ( !IsHashRefWithData($DynamicFieldData) ) {
+        return $Self->{LayoutObject}->ErrorScreen(
+            Message => "Could not get data for dynamic field $FieldID",
+        );
+    }
+
     my $PossibleValues = $Self->_GetPossibleValues();
 
     # set errors for possible values entries
     KEY:
-    for my $Key ( sort keys %{$PossibleValues} ) {
+    for my $Key ( keys %{$PossibleValues} ) {
 
         # check for empty original values
         if ( $Key =~ m{\A $Self->{EmptyString} (?: \d+)}smx ) {
@@ -547,7 +539,6 @@ sub _ShowScreen {
         Name          => 'FieldOrder',
         SelectedValue => $Param{FieldOrder} || 1,
         PossibleNone  => 0,
-        Translation   => 0,
         Class         => 'W50pc Validate_Number',
     );
 
@@ -646,7 +637,7 @@ sub _ShowScreen {
     # check and build the Default Value list based on Possible Values
     my %DefaultValuesList;
     POSSIBLEVALUE:
-    for my $ValueItem ( sort keys %PossibleValues ) {
+    for my $ValueItem ( keys %PossibleValues ) {
         next POSSIBLEVALUE if !defined $ValueItem;
         next POSSIBLEVALUE if !defined $PossibleValues{$ValueItem};
         $DefaultValuesList{$ValueItem} = $PossibleValues{$ValueItem}
@@ -696,17 +687,6 @@ sub _ShowScreen {
         Class      => 'W50pc',
     );
 
-    my $ReadonlyInternalField = '';
-
-    # Internal fields can not be deleted and name should not change.
-    if ( $Param{InternalField} ) {
-        $Self->{LayoutObject}->Block(
-            Name => 'InternalField',
-            Data => {%Param},
-        );
-        $ReadonlyInternalField = 'readonly="readonly"';
-    }
-
     # generate output
     $Output .= $Self->{LayoutObject}->Output(
         TemplateFile => 'AdminDynamicFieldMultiselect',
@@ -718,7 +698,6 @@ sub _ShowScreen {
             DefaultValueStrg       => $DefaultValueStrg,
             PossibleNoneStrg       => $PossibleNoneStrg,
             TranslatableValuesStrg => $TranslatableValuesStrg,
-            ReadonlyInternalField  => $ReadonlyInternalField,
             }
     );
 
