@@ -1,6 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketPhoneCommon.pm - phone calls for existing tickets
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# --
+# $Id: AgentTicketPhoneCommon.pm,v 1.22 2012/02/29 14:36:19 ep Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,8 +14,6 @@ package Kernel::Modules::AgentTicketPhoneCommon;
 use strict;
 use warnings;
 
-use Mail::Address;
-
 use Kernel::System::SystemAddress;
 use Kernel::System::CustomerUser;
 use Kernel::System::CheckItem;
@@ -22,7 +22,10 @@ use Kernel::System::State;
 use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
 use Kernel::System::VariableCheck qw(:all);
-use Kernel::System::TemplateGenerator;
+use Mail::Address;
+
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.22 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -33,7 +36,7 @@ sub new {
 
     # check needed objects
     for my $Needed (
-        qw(ParamObject DBObject TicketObject LayoutObject LogObject QueueObject MainObject ConfigObject)
+        qw(ParamObject DBObject TicketObject LayoutObject LogObject QueueObject ConfigObject)
         )
     {
         if ( !$Self->{$Needed} ) {
@@ -112,7 +115,7 @@ sub Run {
     );
     my %AclAction = $Self->{TicketObject}->TicketAclActionData();
 
-    # check if ACL restrictions exist
+    # check if ACL resctictions if exist
     if ( IsHashRefWithData( \%AclAction ) ) {
 
         # show error screen if ACL prohibits this action
@@ -160,8 +163,8 @@ sub Run {
                     Type  => 'Small',
                 );
                 $Output .= $Self->{LayoutObject}->Warning(
-                    Message => $Self->{LayoutObject}->{LanguageObject}->Get('Sorry, you need to be the ticket owner to perform this action.'),
-                    Comment => $Self->{LayoutObject}->{LanguageObject}->Get('Please change the owner first.'),
+                    Message => 'Sorry, you need to be the ticket owner to perform this action.',
+                    Comment => 'Please change the owner first.',
                 );
                 $Output .= $Self->{LayoutObject}->Footer(
                     Type => 'Small',
@@ -192,7 +195,7 @@ sub Run {
     # get dynamic field values form http request
     my %DynamicFieldValues;
 
-    # cycle through the activated Dynamic Fields for this screen
+    # cycle trough the activated Dynamic Fields for this screen
     DYNAMICFIELD:
     for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
         next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
@@ -209,7 +212,7 @@ sub Run {
     # convert dynamic field values into a structure for ACLs
     my %DynamicFieldACLParameters;
     DYNAMICFIELD:
-    for my $DynamicField ( sort keys %DynamicFieldValues ) {
+    for my $DynamicField ( keys %DynamicFieldValues ) {
         next DYNAMICFIELD if !$DynamicField;
         next DYNAMICFIELD if !$DynamicFieldValues{$DynamicField};
 
@@ -252,7 +255,7 @@ sub Run {
         # create html strings for all dynamic fields
         my %DynamicFieldHTML;
 
-        # cycle through the activated Dynamic Fields for this screen
+        # cycle trough the activated Dynamic Fields for this screen
         DYNAMICFIELD:
         for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
             next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
@@ -262,10 +265,6 @@ sub Run {
             # check if field has PossibleValues property in its configuration
             if ( IsHashRefWithData( $DynamicFieldConfig->{Config}->{PossibleValues} ) ) {
 
-                # convert possible values key => value to key => key for ACLs using a Hash slice
-                my %AclData = %{ $DynamicFieldConfig->{Config}->{PossibleValues} };
-                @AclData{ keys %AclData } = keys %AclData;
-
                 # set possible values filter from ACLs
                 my $ACL = $Self->{TicketObject}->TicketAcl(
                     %GetParam,
@@ -273,16 +272,12 @@ sub Run {
                     TicketID      => $Self->{TicketID},
                     ReturnType    => 'Ticket',
                     ReturnSubType => 'DynamicField_' . $DynamicFieldConfig->{Name},
-                    Data          => \%AclData,
+                    Data          => $DynamicFieldConfig->{Config}->{PossibleValues},
                     UserID        => $Self->{UserID},
                 );
                 if ($ACL) {
                     my %Filter = $Self->{TicketObject}->TicketAclData();
-
-                    # convert Filer key => key back to key => value using map
-                    %{$PossibleValuesFilter}
-                        = map { $_ => $DynamicFieldConfig->{Config}->{PossibleValues}->{$_} }
-                        keys %Filter;
+                    $PossibleValuesFilter = \%Filter;
                 }
             }
 
@@ -435,7 +430,7 @@ sub Run {
         # create html strings for all dynamic fields
         my %DynamicFieldHTML;
 
-        # cycle through the activated Dynamic Fields for this screen
+        # cycle trough the activated Dynamic Fields for this screen
         DYNAMICFIELD:
         for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
             next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
@@ -445,10 +440,6 @@ sub Run {
             # check if field has PossibleValues property in its configuration
             if ( IsHashRefWithData( $DynamicFieldConfig->{Config}->{PossibleValues} ) ) {
 
-                # convert possible values key => value to key => key for ACLs using a Hash slice
-                my %AclData = %{ $DynamicFieldConfig->{Config}->{PossibleValues} };
-                @AclData{ keys %AclData } = keys %AclData;
-
                 # set possible values filter from ACLs
                 my $ACL = $Self->{TicketObject}->TicketAcl(
                     %GetParam,
@@ -456,16 +447,12 @@ sub Run {
                     TicketID      => $Self->{TicketID},
                     ReturnType    => 'Ticket',
                     ReturnSubType => 'DynamicField_' . $DynamicFieldConfig->{Name},
-                    Data          => \%AclData,
+                    Data          => $DynamicFieldConfig->{Config}->{PossibleValues},
                     UserID        => $Self->{UserID},
                 );
                 if ($ACL) {
                     my %Filter = $Self->{TicketObject}->TicketAclData();
-
-                    # convert Filer key => key back to key => value using map
-                    %{$PossibleValuesFilter}
-                        = map { $_ => $DynamicFieldConfig->{Config}->{PossibleValues}->{$_} }
-                        keys %Filter;
+                    $PossibleValuesFilter = \%Filter;
                 }
             }
 
@@ -617,28 +604,11 @@ sub Run {
                 );
             }
 
-            # Use customer data as From, if possible
-            my %LastCustomerArticle = $Self->{TicketObject}->ArticleLastCustomerArticle(
-                TicketID      => $Self->{TicketID},
-                DynamicFields => 0,
-            );
-
-            my $From = $LastCustomerArticle{From};
-
-            # If we don't have a customer article, use the agent as From
-            if (!$From) {
-                my $TemplateGenerator = Kernel::System::TemplateGenerator->new( %{$Self} );
-                $From = $TemplateGenerator->Sender(
-                    QueueID => $Ticket{QueueID},
-                    UserID  => $Self->{UserID},
-                );
-            }
-
             my $ArticleID = $Self->{TicketObject}->ArticleCreate(
                 TicketID    => $Self->{TicketID},
                 ArticleType => $Self->{Config}->{ArticleType},
                 SenderType  => $Self->{Config}->{SenderType},
-                From        => $From,
+                From        => "$Self->{UserFirstname} $Self->{UserLastname} <$Self->{UserEmail}>",
                 Subject     => $GetParam{Subject},
                 Body        => $GetParam{Body},
                 MimeType    => $MimeType,
@@ -676,12 +646,12 @@ sub Run {
             $Self->{UploadCacheObject}->FormIDRemove( FormID => $Self->{FormID} );
 
             # set dynamic fields
-            # cycle through the activated Dynamic Fields for this screen
+            # cycle trough the activated Dynamic Fields for this screen
             DYNAMICFIELD:
             for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
                 next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
 
-                # set the object ID (TicketID or ArticleID) depending on the field configuration
+                # set the object ID (TicketID or ArticleID) depending on the field configration
                 my $ObjectID
                     = $DynamicFieldConfig->{ObjectType} eq 'Article'
                     ? $ArticleID
@@ -746,10 +716,10 @@ sub Run {
             %GetParam,
         );
 
-        # update Dynamic Fields Possible Values via AJAX
+        # update Dynamc Fields Possible Values via AJAX
         my @DynamicFieldAJAX;
 
-        # cycle through the activated Dynamic Fields for this screen
+        # cycle trough the activated Dynamic Fields for this screen
         DYNAMICFIELD:
         for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
             next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
@@ -763,10 +733,6 @@ sub Run {
                 DynamicFieldConfig => $DynamicFieldConfig,
             );
 
-            # convert possible values key => value to key => key for ACLs using a Hash slice
-            my %AclData = %{$PossibleValues};
-            @AclData{ keys %AclData } = keys %AclData;
-
             # set possible values filter from ACLs
             my $ACL = $Self->{TicketObject}->TicketAcl(
                 %GetParam,
@@ -774,14 +740,12 @@ sub Run {
                 TicketID      => $Self->{TicketID},
                 ReturnType    => 'Ticket',
                 ReturnSubType => 'DynamicField_' . $DynamicFieldConfig->{Name},
-                Data          => \%AclData,
+                Data          => $PossibleValues,
                 UserID        => $Self->{UserID},
             );
             if ($ACL) {
                 my %Filter = $Self->{TicketObject}->TicketAclData();
-
-                # convert Filer key => key back to key => value using map
-                %{$PossibleValues} = map { $_ => $PossibleValues->{$_} } keys %Filter;
+                $PossibleValues = \%Filter;
             }
 
             # add dynamic field to the list of fields to update
@@ -847,7 +811,7 @@ sub _GetUsers {
     # just show only users with selected custom queue
     if ( $Param{QueueID} && !$Param{AllUsers} ) {
         my @UserIDs = $Self->{TicketObject}->GetSubscribedUserIDsByQueueID(%Param);
-        for my $KeyGroupMember ( sort keys %AllGroupsMembers ) {
+        for my $KeyGroupMember ( keys %AllGroupsMembers ) {
             my $Hit = 0;
             for my $UID (@UserIDs) {
                 if ( $UID eq $KeyGroupMember ) {
@@ -873,7 +837,7 @@ sub _GetUsers {
             Type    => 'rw',
             Result  => 'HASH',
         );
-        for my $KeyMember ( sort keys %MemberList ) {
+        for my $KeyMember ( keys %MemberList ) {
             $ShownUsers{$KeyMember} = $AllGroupsMembers{$KeyMember};
         }
     }
@@ -915,14 +879,14 @@ sub _GetTos {
             Type   => 'create',
             Result => 'HASH',
         );
-        for my $KeyTo ( sort keys %Tos ) {
+        for my $KeyTo ( keys %Tos ) {
             if ( $UserGroups{ $Self->{QueueObject}->GetQueueGroupID( QueueID => $KeyTo ) } ) {
                 $NewTos{$KeyTo} = $Tos{$KeyTo};
             }
         }
 
         # build selection string
-        for my $KeyNewTo ( sort keys %NewTos ) {
+        for my $KeyNewTo ( keys %NewTos ) {
             my %QueueData = $Self->{QueueObject}->QueueGet( ID => $KeyNewTo );
             my $Srting = $Self->{ConfigObject}->Get('Ticket::Frontend::NewQueueSelectionString')
                 || '<Realname> <<Email>> - Queue: <Queue>';
@@ -939,7 +903,7 @@ sub _GetTos {
         }
     }
 
-    # add empty selection
+    # adde empty selection
     $NewTos{''} = '-';
     return \%NewTos;
 }
@@ -1016,14 +980,14 @@ sub _MaskPhone {
 
     # prepare errors!
     if ( $Param{Errors} ) {
-        for my $KeyError ( sort keys %{ $Param{Errors} } ) {
+        for my $KeyError ( keys %{ $Param{Errors} } ) {
             $Param{$KeyError}
                 = '* ' . $Self->{LayoutObject}->Ascii2Html( Text => $Param{Errors}->{$KeyError} );
         }
     }
 
     # Dynamic fields
-    # cycle through the activated Dynamic Fields for this screen
+    # cycle trough the activated Dynamic Fields for this screen
     DYNAMICFIELD:
     for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
         next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
@@ -1101,11 +1065,6 @@ sub _MaskPhone {
 
     # add rich text editor
     if ( $Self->{LayoutObject}->{BrowserRichText} ) {
-
-        # use height/width defined for this screen
-        $Param{RichTextHeight} = $Self->{Config}->{RichTextHeight} || 0;
-        $Param{RichTextWidth}  = $Self->{Config}->{RichTextWidth}  || 0;
-
         $Self->{LayoutObject}->Block(
             Name => 'RichText',
             Data => \%Param,
@@ -1125,12 +1084,12 @@ sub _GetFieldsToUpdate {
 
     my @UpdatableFields;
 
-    # set the fields that can be updateable via AJAXUpdate
+    # set the fields that can be updatable via AJAXUpdate
     if ( !$Param{OnlyDynamicFields} ) {
         @UpdatableFields = qw( NextStateID );
     }
 
-    # cycle through the activated Dynamic Fields for this screen
+    # cycle trough the activated Dynamic Fields for this screen
     DYNAMICFIELD:
     for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
         next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
