@@ -1,8 +1,8 @@
 # --
 # Kernel/System/DB.pm - the global database wrapper to support different databases
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: DB.pm,v 1.127.2.7 2012/08/06 14:47:32 mg Exp $
+# $Id: DB.pm,v 1.144 2011/12/12 16:23:14 jp Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,9 +17,10 @@ use warnings;
 use DBI;
 
 use Kernel::System::Time;
+use Kernel::System::VariableCheck qw(:all);
 
 use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.127.2.7 $) [1];
+$VERSION = qw($Revision: 1.144 $) [1];
 
 =head1 NAME
 
@@ -88,23 +89,28 @@ sub new {
     # 0=off; 1=updates; 2=+selects; 3=+Connects;
     $Self->{Debug} = $Param{Debug} || 0;
 
-    # check needed objects
-    for (qw(ConfigObject LogObject MainObject EncodeObject)) {
-        if ( $Param{$_} ) {
-            $Self->{$_} = $Param{$_};
+    # get needed objects
+    for my $Needed (qw(ConfigObject LogObject MainObject EncodeObject)) {
+        if ( $Param{$Needed} ) {
+            $Self->{$Needed} = $Param{$Needed};
         }
         else {
-            die "Got no $_!";
+            die "Got no $Needed!";
         }
     }
 
-    # time object
-    $Self->{TimeObject} = Kernel::System::Time->new( %{$Self} );
+    if ( $Param{TimeObject} ) {
+        $Self->{TimeObject} = $Param{TimeObject};
+    }
+    else {
+        $Self->{TimeObject} = Kernel::System::Time->new( %{$Self} );
+    }
 
     # get config data
     $Self->{DSN}  = $Param{DatabaseDSN}  || $Self->{ConfigObject}->Get('DatabaseDSN');
     $Self->{USER} = $Param{DatabaseUser} || $Self->{ConfigObject}->Get('DatabaseUser');
     $Self->{PW}   = $Param{DatabasePw}   || $Self->{ConfigObject}->Get('DatabasePw');
+
     $Self->{SlowLog} = $Param{'Database::SlowLog'}
         || $Self->{ConfigObject}->Get('Database::SlowLog');
 
@@ -118,7 +124,12 @@ sub new {
         $Self->{'DB::Type'} = 'mysql';
     }
     elsif ( $Self->{DSN} =~ /:pg/i ) {
-        $Self->{'DB::Type'} = 'postgresql';
+        if ( $Self->{ConfigObject}->Get('DatabasePostgresqlBefore82') ) {
+            $Self->{'DB::Type'} = 'postgresql_before_8_2';
+        }
+        else {
+            $Self->{'DB::Type'} = 'postgresql';
+        }
     }
     elsif ( $Self->{DSN} =~ /:oracle/i ) {
         $Self->{'DB::Type'} = 'oracle';
@@ -177,6 +188,41 @@ sub new {
         }
     }
 
+    # Check for registered listener objects
+    $Self->{DBListeners} = [];
+
+    my $DBListeners = $Self->{ConfigObject}->Get('DB::DBListener');
+
+    if ( IsHashRefWithData($DBListeners) ) {
+
+        KEY:
+        for my $Key ( sort keys %{$DBListeners} ) {
+
+            if ( IsHashRefWithData( $DBListeners->{$Key} ) && $DBListeners->{$Key}->{Object} ) {
+                my $Object = $DBListeners->{$Key}->{Object};
+                if ( !$Self->{MainObject}->Require($Object) ) {
+                    $Self->{'LogObject'}->Log(
+                        'Priority' => 'error',
+                        'Message'  => "Could not load module $Object",
+                    );
+
+                    next KEY;
+                }
+                my $Instance = $Object->new(%Param);
+                if ( ref $Instance ne $Object ) {
+                    $Self->{'LogObject'}->Log(
+                        'Priority' => 'error',
+                        'Message'  => "Could not instantiate module $Object",
+                    );
+
+                    next KEY;
+                }
+
+                push @{ $Self->{DBListeners} }, $Instance;
+            }
+        }
+    }
+
     # do database connect
     if ( !$Param{AutoConnectNo} ) {
         return if !$Self->Connect();
@@ -213,6 +259,7 @@ sub Connect {
         $Self->{PW},
         $Self->{Backend}->{'DB::Attribute'},
     );
+
     if ( !$Self->{dbh} ) {
         $Self->{LogObject}->Log(
             Caller   => 1,
@@ -221,9 +268,11 @@ sub Connect {
         );
         return;
     }
+
     if ( $Self->{Backend}->{'DB::Connect'} ) {
         $Self->Do( SQL => $Self->{Backend}->{'DB::Connect'} );
     }
+
     return $Self->{dbh};
 }
 
@@ -251,6 +300,7 @@ sub Disconnect {
     if ( $Self->{dbh} ) {
         $Self->{dbh}->disconnect();
     }
+
     return 1;
 }
 
@@ -321,6 +371,7 @@ sub Quote {
         Priority => 'error',
         Message  => "Invalid quote type '$Type'!",
     );
+
     return;
 }
 
@@ -384,19 +435,20 @@ sub Do {
             }
         }
     }
-    if ( !$Self->{ConfigObject}->Get('TimeZone') ) {
 
-        # timestamp workaround (if needed)
-        if ( $Self->{Backend}->{'DB::CurrentTimestamp'} ) {
-            $Param{SQL} =~ s/current_timestamp/$Self->{Backend}->{'DB::CurrentTimestamp'}/g;
-        }
-    }
-    else {
-
-        # replace current_timestamp
-        my $Timestamp = $Self->{TimeObject}->CurrentTimestamp();
-        $Param{SQL} =~ s/(\s|\(|,| )current_timestamp(\s|\)|,| )/$1'$Timestamp'$2/g;
+    # Replace current_timestamp with real time stamp.
+    # - This avoids time inconsistencies of app and db server
+    # - This avoids timestamp problems in Postgresql servers where
+    #   the timestamp is sometimes 1 second off the perl timestamp.
+    my $Timestamp = $Self->{TimeObject}->CurrentTimestamp();
+    $Param{SQL} =~ s{
+        (?<= \s | \( | , )  # lookahead
+        current_timestamp   # replace current_timestamp by 'yyyy-mm-dd hh:mm:ss'
+        (?=  \s | \) | , )  # lookbehind
     }
+    {
+        '$Timestamp'
+    }xmsg;
 
     # debug
     if ( $Self->{Debug} > 0 ) {
@@ -418,6 +470,10 @@ sub Do {
         );
     }
 
+    for my $DBListener ( @{ $Self->{DBListeners} } ) {
+        $DBListener->PreDo( SQL => $Param{SQL}, Bind => \@Array );
+    }
+
     # send sql to database
     if ( !$Self->{dbh}->do( $Param{SQL}, undef, @Array ) ) {
         $Self->{LogObject}->Log(
@@ -427,6 +483,11 @@ sub Do {
         );
         return;
     }
+
+    for my $DBListener ( @{ $Self->{DBListeners} } ) {
+        $DBListener->PostDo( SQL => $Param{SQL}, Bind => \@Array );
+    }
+
     return 1;
 }
 
@@ -459,7 +520,7 @@ you also can use DBI bind values, required for large strings:
     my $Var1 = 'dog1';
     my $Var2 = 'dog2';
 
-    $DBObject->Do(
+    $DBObject->Prepare(
         SQL    => "SELECT id, name, content FROM table WHERE name_a = ? AND name_b = ?",
         Encode => [ 1, 1, 0 ],
         Bind   => [ \$Var1, \$Var2 ],
@@ -540,6 +601,10 @@ sub Prepare {
         }
     }
 
+    for my $DBListener ( @{ $Self->{DBListeners} } ) {
+        $DBListener->PrePrepare( SQL => $SQL, Bind => \@Array );
+    }
+
     # do
     if ( !( $Self->{Cursor} = $Self->{dbh}->prepare($SQL) ) ) {
         $Self->{LogObject}->Log(
@@ -559,6 +624,10 @@ sub Prepare {
         return;
     }
 
+    for my $DBListener ( @{ $Self->{DBListeners} } ) {
+        $DBListener->PostPrepare( SQL => $SQL, Bind => \@Array );
+    }
+
     # slow log feature
     if ( $Self->{SlowLog} ) {
         my $LogTimeTaken = time() - $LogTime;
@@ -638,6 +707,41 @@ sub FetchrowArray {
     return @Row;
 }
 
+=item SelectAll()
+
+returns all available records of a SELECT statement.
+In essence, this calls Prepare() and FetchrowArray() to get all records.
+
+    my $ResultAsArrayRef = $DBObject->SelectAll(
+        SQL   => "SELECT id, name FROM table",
+        Limit => 10
+    );
+
+You can pass the same arguments as to the Prepare() method.
+
+Returns undef (if query failed), or an array ref (if query was successful):
+
+  my $ResultAsArrayRef = [
+    [ 1, 'itemOne' ],
+    [ 2, 'itemTwo' ],
+    [ 3, 'itemThree' ],
+    [ 4, 'itemFour' ],
+  ];
+
+=cut
+
+sub SelectAll {
+    my ( $Self, %Param ) = @_;
+
+    return if !$Self->Prepare(%Param);
+
+    my @Records;
+    while ( my @Row = $Self->FetchrowArray() ) {
+        push @Records, \@Row;
+    }
+    return \@Records;
+}
+
 =item GetDatabaseFunction()
 
 to get database functions like
@@ -696,9 +800,10 @@ generate database-specific sql syntax (e. g. CREATE TABLE ...)
 sub SQLProcessor {
     my ( $Self, %Param ) = @_;
 
-    my @SQL = ();
+    my @SQL;
     if ( $Param{Database} && ref $Param{Database} eq 'ARRAY' ) {
-        my @Table = ();
+
+        my @Table;
         for my $Tag ( @{ $Param{Database} } ) {
 
             # create table
@@ -723,7 +828,6 @@ sub SQLProcessor {
                 push @Table, $Tag;
             }
 
-            #            elsif ( $Tag->{Tag} eq 'UniqueColumn' && $Tag->{TagType} eq 'Start' ) {
             elsif ( $Tag->{Tag} eq 'UniqueColumn' ) {
                 push @Table, $Tag;
             }
@@ -738,7 +842,6 @@ sub SQLProcessor {
                 push @Table, $Tag;
             }
 
-            #            elsif ( $Tag->{Tag} eq 'IndexColumn' && $Tag->{TagType} eq 'Start' ) {
             elsif ( $Tag->{Tag} eq 'IndexColumn' ) {
                 push @Table, $Tag;
             }
@@ -812,6 +915,7 @@ sub SQLProcessor {
             }
         }
     }
+
     return @SQL;
 }
 
@@ -832,6 +936,7 @@ sub SQLProcessorPost {
         undef $Self->{Backend}->{Post};
         return @Return;
     }
+
     return ();
 }
 
@@ -865,7 +970,9 @@ sub GetTableData {
 
         $SQL .= " WHERE valid_id IN ( ${\(join ', ', @ValidIDs)} )";
     }
+
     $Self->Prepare( SQL => $SQL );
+
     while ( my @Row = $Self->FetchrowArray() ) {
         if ( $Row[3] ) {
             if ($Clamp) {
@@ -887,6 +994,7 @@ sub GetTableData {
             $Data{ $Row[0] } = $Row[1];
         }
     }
+
     return %Data;
 }
 
@@ -1046,11 +1154,32 @@ sub QueryCondition {
             )
 
             # "default" case: don't add brackets, etc. to a word being searched for
-            || $Array[$Position] !~ /(\(|\)|\!|\||&)/
+            || $Array[$Position] !~ /(\(|\)|\!|\|)/
             )
         {
-            $Word .= $Array[$Position];
-            next POSITION;
+            if ( $Array[$Position] =~ m{&} ) {
+                if (
+                    !(
+                        (
+                            $Array[ $Position - 1 ]
+                            && $Array[ $Position - 1 ] =~ m{&}
+                        )
+                        ||
+                        (
+                            $Array[ $Position + 1 ]
+                            && $Array[ $Position + 1 ] =~ m{&}
+                        )
+                    )
+                    )
+                {
+                    $Word .= $Array[$Position];
+                    next POSITION;
+                }
+            }
+            else {
+                $Word .= $Array[$Position];
+                next POSITION;
+            }
         }
 
         # if word exists, do something with it
@@ -1081,6 +1210,7 @@ sub QueryCondition {
             # if it's a NOT LIKE condition
             if ( $Array[$Position] eq '!' || $Not ) {
                 $Not = 0;
+
                 my $SQLA;
                 for my $Key (@Keys) {
                     if ($SQLA) {
@@ -1195,6 +1325,7 @@ sub QueryCondition {
         );
         return;
     }
+
     return $SQL;
 }
 
@@ -1219,7 +1350,7 @@ sub QueryStringEscape {
     # check needed stuff
     for my $Key (qw(QueryString)) {
         if ( !defined $Param{$Key} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Key!" );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
@@ -1288,6 +1419,7 @@ sub _TypeCheck {
             Message  => "Unknown data type '$Tag->{Type}'!",
         );
     }
+
     return 1;
 }
 
@@ -1300,6 +1432,7 @@ sub _NameCheck {
             Message  => "Table names should not have more the 30 chars ($Tag->{Name})!",
         );
     }
+
     return 1;
 }
 
@@ -1310,7 +1443,7 @@ sub _SpecialCharactersGet {
         '(' => 1,
         ')' => 1,
         '&' => 1,
-        '|' => 1,
+        '-' => 1,
     );
 
     return \%SpecialCharacter;
@@ -1346,6 +1479,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.127.2.7 $ $Date: 2012/08/06 14:47:32 $
+$Revision: 1.144 $ $Date: 2011/12/12 16:23:14 $
 
 =cut
