@@ -1,6 +1,8 @@
 # --
 # Kernel/System/Type.pm - All type related function should be here eventually
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# --
+# $Id: Type.pm,v 1.25 2011/02/11 14:43:01 bes Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,10 +14,11 @@ package Kernel::System::Type;
 use strict;
 use warnings;
 
-use Kernel::System::CacheInternal;
 use Kernel::System::Valid;
+use Kernel::System::CacheInternal;
 
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
+$VERSION = qw($Revision: 1.25 $) [1];
 
 =head1 NAME
 
@@ -86,7 +89,7 @@ sub new {
     $Self->{CacheInternalObject} = Kernel::System::CacheInternal->new(
         %{$Self},
         Type => 'Type',
-        TTL  => 60 * 60 * 24 * 20,
+        TTL  => 60 * 60 * 3,
     );
 
     return $Self;
@@ -136,8 +139,14 @@ sub TypeAdd {
     }
     return if !$ID;
 
-    # reset cache
-    $Self->{CacheInternalObject}->CleanUp();
+    # delete cache
+    my @CacheKeys = ( 'TypeGet::Name::' . $Param{Name}, 'TypeGet::ID::' . $ID );
+    push @CacheKeys, 'TypeLookup::Name::' . $Param{Name}, 'TypeLookup::ID::' . $ID;
+    push @CacheKeys, 'TypeList::Valid::0';
+    push @CacheKeys, 'TypeList::Valid::1';
+    for my $CacheKey (@CacheKeys) {
+        $Self->{CacheInternalObject}->Delete( Key => $CacheKey );
+    }
 
     return $ID;
 }
@@ -228,6 +237,9 @@ sub TypeGet {
         $Type{ChangeBy}   = $Data[6];
     }
 
+    # set cache
+    $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => \%Type );
+
     # no data found
     if ( !%Type ) {
         $Self->{LogObject}->Log(
@@ -237,9 +249,6 @@ sub TypeGet {
         return;
     }
 
-    # set cache
-    $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => \%Type );
-
     return %Type;
 }
 
@@ -276,8 +285,14 @@ sub TypeUpdate {
         ],
     );
 
-    # reset cache
-    $Self->{CacheInternalObject}->CleanUp();
+    # delete cache
+    my @CacheKeys = ( 'TypeGet::Name::' . $Param{Name}, 'TypeGet::ID::' . $Param{ID} );
+    push @CacheKeys, 'TypeLookup::Name::' . $Param{Name}, 'TypeLookup::ID::' . $Param{ID};
+    push @CacheKeys, 'TypeList::Valid::0';
+    push @CacheKeys, 'TypeList::Valid::1';
+    for my $CacheKey (@CacheKeys) {
+        $Self->{CacheInternalObject}->Delete( Key => $CacheKey );
+    }
 
     return 1;
 }
@@ -307,6 +322,7 @@ sub TypeList {
 
     # check cache
     my $CacheKey = "TypeList::Valid::$Valid";
+
     my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
     return %{$Cache} if $Cache;
 
@@ -360,36 +376,63 @@ sub TypeLookup {
         return;
     }
 
-    # get (already cached) type list
-    my %TypeList = $Self->TypeList(
-        Valid => 0,
-    );
-
+    # check cache
+    my $CacheKey;
     my $Key;
     my $Value;
-    my $ReturnData;
     if ( $Param{TypeID} ) {
-        $Key        = 'TypeID';
-        $Value      = $Param{TypeID};
-        $ReturnData = $TypeList{ $Param{TypeID} };
+        $CacheKey = 'TypeLookup::ID::' . $Param{TypeID};
+        $Key      = 'TypeID';
+        $Value    = $Param{TypeID};
     }
     else {
-        $Key   = 'Type';
-        $Value = $Param{Type};
-        my %TypeListReverse = reverse %TypeList;
-        $ReturnData = $TypeListReverse{ $Param{Type} };
+        $CacheKey = 'TypeLookup::Name::' . $Param{Type};
+        $Key      = 'Type';
+        $Value    = $Param{Type};
+    }
+
+    my $Cache = $Self->{CacheInternalObject}->Get( Key => $CacheKey );
+    return $Cache if $Cache;
+
+    # get data
+    my $SQL;
+    my @Bind;
+    my $Suffix = '';
+    if ( $Param{Type} ) {
+        $SQL = 'SELECT id FROM ticket_type WHERE name = ?';
+        push @Bind, \$Param{Type};
+    }
+    else {
+        $SQL = 'SELECT name FROM ticket_type WHERE id = ?';
+        push @Bind, \$Param{TypeID};
+    }
+
+    # ask the database
+    return if !$Self->{DBObject}->Prepare(
+        SQL   => $SQL,
+        Bind  => \@Bind,
+        Limit => 1,
+    );
+
+    # fetch the result
+    my $Data;
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+        $Data = $Row[0];
     }
 
     # check if data exists
-    if ( !defined $ReturnData ) {
+    if ( !$Data ) {
         $Self->{LogObject}->Log(
             Priority => 'error',
-            Message  => "No $Key for $Value found!",
+            Message  => "Found no $Key for $Value!",
         );
         return;
     }
 
-    return $ReturnData;
+    # set cache
+    $Self->{CacheInternalObject}->Set( Key => $CacheKey, Value => $Data );
+
+    return $Data;
 }
 
 1;
@@ -405,3 +448,9 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
+
+=head1 VERSION
+
+$Revision: 1.25 $ $Date: 2011/02/11 14:43:01 $
+
+=cut
